==> jc-1.4.0.tar.gz: java/net/SocketAddress.h <==
// public abstract class java.net.SocketAddress

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 45e49f95a1f57a78 java_net_SocketAddress

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_net_SocketAddress_H_
#define _JC_java_net_SocketAddress_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_net_SocketAddress$sub_refs	_jc_java_net_SocketAddress$sub_refs;
typedef struct _jc_java_net_SocketAddress$sub_nonrefs	_jc_java_net_SocketAddress$sub_nonrefs;
typedef struct _jc_java_net_SocketAddress$refs	_jc_java_net_SocketAddress$refs;
typedef struct _jc_java_net_SocketAddress$nonrefs	_jc_java_net_SocketAddress$nonrefs;
typedef struct _jc_java_net_SocketAddress$object	_jc_java_net_SocketAddress$object;

typedef struct _jc_java_net_SocketAddress$fields_struct	_jc_java_net_SocketAddress$fields_struct;
typedef const struct _jc_java_net_SocketAddress$vmethods	_jc_java_net_SocketAddress$vmethods;
typedef const struct _jc_java_net_SocketAddress$vtable	_jc_java_net_SocketAddress$vtable;
typedef const struct _jc_java_net_SocketAddress$vtype	_jc_java_net_SocketAddress$vtype;

// Class fields structure
struct _jc_java_net_SocketAddress$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_SocketAddress$fields_struct _jc_java_net_SocketAddress$class_fields;

// Constructors
extern void _jc_java_net_SocketAddress$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_SocketAddress$object *);

// Virtual methods structure
struct _jc_java_net_SocketAddress$vmethods {
};

// Vtable
struct _jc_java_net_SocketAddress$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_SocketAddress$vmethods	java_net_SocketAddress;
};

// Vtype
struct _jc_java_net_SocketAddress$vtype {
	_jc_type			type;
	_jc_java_net_SocketAddress$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_SocketAddress$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_SocketAddress$refs {
    _jc_java_net_SocketAddress$sub_refs	java_net_SocketAddress;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_SocketAddress$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_SocketAddress$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_SocketAddress$sub_nonrefs	java_net_SocketAddress;
};

// Object instance structure
struct _jc_java_net_SocketAddress$object {
	_jc_java_net_SocketAddress$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_SocketAddress$vtype	*vtype;
	_jc_java_net_SocketAddress$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_SocketAddress$vtype _jc_java_net_SocketAddress$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_SocketAddress, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_SocketAddress$class_object;

#endif	/* _JC_java_net_SocketAddress_H_ */

==> jc-1.4.6.tar.gz: java/net/SocketAddress.h <==
// public abstract class java.net.SocketAddress

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 45e49f95a1f57a78 java_net_SocketAddress

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_net_SocketAddress_H_
#define _JC_java_net_SocketAddress_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_net_SocketAddress$sub_refs	_jc_java_net_SocketAddress$sub_refs;
typedef struct _jc_java_net_SocketAddress$sub_nonrefs	_jc_java_net_SocketAddress$sub_nonrefs;
typedef struct _jc_java_net_SocketAddress$refs	_jc_java_net_SocketAddress$refs;
typedef struct _jc_java_net_SocketAddress$nonrefs	_jc_java_net_SocketAddress$nonrefs;
typedef struct _jc_java_net_SocketAddress$object	_jc_java_net_SocketAddress$object;

typedef struct _jc_java_net_SocketAddress$fields_struct	_jc_java_net_SocketAddress$fields_struct;
typedef const struct _jc_java_net_SocketAddress$vmethods	_jc_java_net_SocketAddress$vmethods;
typedef const struct _jc_java_net_SocketAddress$vtable	_jc_java_net_SocketAddress$vtable;
typedef const struct _jc_java_net_SocketAddress$vtype	_jc_java_net_SocketAddress$vtype;

// Class fields structure
struct _jc_java_net_SocketAddress$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_SocketAddress$fields_struct _jc_java_net_SocketAddress$class_fields;

// Constructors
extern void _jc_java_net_SocketAddress$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_SocketAddress$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_net_SocketAddress$vmethods {
};

// Vtable
struct _jc_java_net_SocketAddress$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_SocketAddress$vmethods	java_net_SocketAddress;
};

// Vtype
struct _jc_java_net_SocketAddress$vtype {
	_jc_type			type;
	_jc_java_net_SocketAddress$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_SocketAddress$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_SocketAddress$refs {
    _jc_java_net_SocketAddress$sub_refs	java_net_SocketAddress;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_SocketAddress$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_SocketAddress$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_SocketAddress$sub_nonrefs	java_net_SocketAddress;
};

// Object instance structure
struct _jc_java_net_SocketAddress$object {
	_jc_java_net_SocketAddress$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_SocketAddress$vtype	*vtype;
	_jc_java_net_SocketAddress$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_SocketAddress$vtype _jc_java_net_SocketAddress$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_SocketAddress, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_SocketAddress$class_object;

#endif	/* _JC_java_net_SocketAddress_H_ */
